import unittest
from MoinMoin.action import SlideShow


class WikiSlideParserTestCase(unittest.TestCase):

    def setUp(self):
        self.p = SlideShow.WikiSlideParser()
        self.slides = []

    def testNoHeadings(self):
        """ SlideShow.WikiSlideParser: no slides """
        self.parse("No slides here\n")
        self.assertEqual(len(self.slides), 0)

    def testIgnoreTextBeforeHeadings(self):
        """ SlideShow.WikiSlideParser: Ignore text before first heading """
        self.parse("Ignored\n= Slide 1 =\n")
        self.assertEqual(len(self.slides), 1)
        self.assertEqual(self.slides[0][0], "Slide 1")

    def testParseHeadings(self):
        """ SlideShow.WikiSlideParser: parse headings level 1 """
        self.parse("= Slide 1 =\n== Sub topic ==\n")
        self.assertEqual(len(self.slides), 1)
        self.assertEqual(self.slides[0][0], "Slide 1")

    def testIgnoreHeadingsInPre(self):
        """ SlideShow.WikiSlideParser: ignore headings in pre """
        self.parse("= Slide 1 =\n{{{\n= Slide 2 =\n}}}\n")
        self.assertEqual(len(self.slides), 1)

    def testIgnoreHeadingsInComments(self):
        """ SlideShow.WikiSlideParser: ignore headings in comments """
        self.parse("= Slide 1 =\n##= Slide 2 =\n")
        self.assertEqual(len(self.slides), 1)

    def testIgnoreHeadingsInText(self):
        """ SlideShow.WikiSlideParser: ignore headings in comments """
        self.parse("= Slide 1 =\nThis is not a slide: = Slide 2 =\n")
        self.assertEqual(len(self.slides), 1)

    def testStripWhitespaceInTitles(self):
        """ SlideShow.WikiSlideParser: strip whitespace in titles """
        self.parse("=     Slide 1     =\n")
        self.assertEqual(self.slides[0][0], "Slide 1")

    def testParseContent(self):
        """ SlideShow.WikiSlideParser: parse slide content """
        test =      "= Slide 1 =\n\nContent\n\n= Slide 2 =\n"
        expected =               "\nContent\n\n"
        self.parse(test)
        title, start, end = self.slides[0]
        result = test[start:end]
        self.assertEqual(result, expected)

    def parse(self, text):
        for title, start, end in self.p.parse(text):
            self.slides.append((title, start, end))

        
def suite():
    test_cases = [unittest.makeSuite(obj, 'test') 
        for name, obj in globals().items()
        if name.endswith('TestCase')]
    return unittest.TestSuite(test_cases)
    
if __name__ == '__main__':
    unittest.TextTestRunner(verbosity=2).run(suite())
