#!/usr/bin/env python
"""
    Start script for the standalone Wiki server.

    @copyright: 2004-2005 Thomas Waldmann, Nir Soffer
    @license: GNU GPL, see COPYING for details.
"""

# System path configuration

import sys
import os

# Assume that moin is installed at PREFIX
PREFIX = os.path.abspath('../')

# Add the path to MoinMoin and the path to wikiconfig.py to the search path.
sys.path = [os.path.join(PREFIX, 'lib/python2.3/site-packages'),
			os.path.abspath('.')] + sys.path

# Debug mode - show detailed error reports
## import os
## os.environ['MOIN_DEBUG'] = '1'

from MoinMoin.server.standalone import StandaloneConfig, run


class Config(StandaloneConfig):

    # Server name
    # Used to create .log, .pid and .prof files
    name = 'moin'

    # Path to moin shared files
    docs = os.path.join(PREFIX, 'share/moin/htdocs')

    # If you run as root, the server will run with as this user and
    # group (default 'www')
    user = 'www'
    group = 'www'

    # Port (default 8000)
    # To serve privileged port under 1024 you will have to run as root.
    port = 8000

    # Interface (default 'localhost')
    # The default will listen only to localhost.
    # '' will listen to any interface
    interface = 'localhost'

    # Log (default commented)
    # Log is written to stderr or to a file you specify here.
    ##logPath = name + '.log'

    # Server class (default ThreadPoolServer)
    # 'ThreadPoolServer' - create a constant pool of threads, simplified
    # Apache worker mpm.
    # 'ThreadingServer' - serve each request in a new thread. Much
    # slower for static files.
    # 'ForkingServer' - serve each request on a new child process -
    # experimental, slow.
    # 'SimpleServer' - server one request at a time. Fast, low
    # memory footprint.
    # If you set one of the threading servers and threads are not
    # available, the server will fallback to ForkingServer. If fork is
    # not available, the server will fallback to SimpleServer.
    serverClass = 'SimpleServer'

    # Thread limit (default 10)
    # Limit the number of threads created. Ignored on non threaded servers.
    threadLimit = 10

    # Request queue size (default 50)
    # The size of the socket listen backlog.
    requestQueueSize = 50

    # Properties
    # Allow overriding any request property by the value defined in
    # this dict e.g properties = {'script_name': '/mywiki'}.
    properties = {}
    
    # Memory profile (default commented)
    # Useful only if you are a developer or interested in moin memory usage
    # A memory profile named 'moin--2004-09-27--01-24.log' is
    # created each time you start the server.
    ## from MoinMoin.util.profile import Profiler
    ## memoryProfile = Profiler(name, requestsPerSample=100, collect=0)

    # Hotshot profile (default commented)
    # Not compatible with threads - use with SimpleServer only.
    ## hotshotProfile = name + '.prof'


if __name__ == '__main__':
    run(Config)

